@@ -65,7 +65,7 @@ rfbDefaultLog(const char *format, ...)
 
     time(&log_clock);
     strftime(buf, 255, "%d/%m/%Y %X ", localtime(&log_clock));
-    fprintf(stderr,buf);
+    fprintf(stderr, "%s", buf);
 
     vfprintf(stderr, format, args);
     fflush(stderr);
@@ -320,7 +320,10 @@ rfbScreenInfoPtr rfbGetScreen(int* argc,char** argv,
    rfbScreen->inetdSock=-1;
 
    rfbScreen->maxFd=0;
-   rfbScreen->rfbListenSock=-1;
+
+   rfbScreen->rfbListenSock[0] = -1;
+   rfbScreen->rfbListenSockTotal = 0;
+   rfbScreen->netIface = NULL;
 
    rfbScreen->desktopName = strdup("LibVNCServer");
    rfbScreen->rfbAlwaysShared = FALSE;
