@@ -42,7 +42,8 @@ vino_setup_debug_flags (void)
       { "mdns",    VINO_DEBUG_MDNS },
       { "prompt",  VINO_DEBUG_PROMPT },
       { "http",    VINO_DEBUG_HTTP },
-      { "dbus",    VINO_DEBUG_DBUS }
+      { "dbus",    VINO_DEBUG_DBUS },
+      { "upnp",    VINO_DEBUG_UPNP }
     };
   
   env_str = g_getenv ("VINO_SERVER_DEBUG");
